@@ -1,5 +1,5 @@
 package Syntax::Infix::Smartmatch;
-$Syntax::Infix::Smartmatch::VERSION = '0.002';
+$Syntax::Infix::Smartmatch::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -36,7 +36,7 @@ Syntax::Infix::Smartmatch - Smartmatch done right
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ This will always return C<$right>. This particularly is useful in second order c
 
 =item * other
 
-This will return C<$left equ $right> (C<defined $left and $left equ $right>).
+This will return C<$left equ $right> (C<defined $left and $left eq $right>).
 
 =back
 
